@@ -312,9 +312,9 @@ def run_command(cmd, outfile=None, cwd=None, ostream=None, stdout=None, stderr=N
             # as doing a normal 'print'
             #
             rpipe1, wpipe1 = os.pipe()
-            rpipe2, wpipe2 = os.pipe()
+            ##rpipe2, wpipe2 = os.pipe()
             #
-            process = SubprocessMngr(cmd.strip(), stdout=wpipe1, stderr=wpipe2, env=env, shell=shell)
+            process = SubprocessMngr(cmd.strip(), stdout=wpipe1, stderr=wpipe1, env=env, shell=shell)
             GlobalData.current_process = process.process
             #
             # Create a thread to read in stdout and stderr data
@@ -323,9 +323,9 @@ def run_command(cmd, outfile=None, cwd=None, ostream=None, stdout=None, stderr=N
             outt = Thread(target=_read_data, args=(rpipe1, sys.stdout, stdout_arg))
             outt.daemon = True
             outt.start()
-            errt = Thread(target=_read_data, args=(rpipe2, sys.stderr, stderr_arg))
-            errt.daemon = True
-            errt.start()
+            ##errt = Thread(target=_read_data, args=(rpipe2, sys.stderr, stderr_arg))
+            ##errt.daemon = True
+            ##errt.start()
             #
             # Wait for process to finish
             #
@@ -335,16 +335,16 @@ def run_command(cmd, outfile=None, cwd=None, ostream=None, stdout=None, stderr=N
             # 'Closing' the PIPE to send EOF to the reader.
             #
             os.close(wpipe1)
-            os.close(wpipe2)
+            ##os.close(wpipe2)
             #
             # Wait for readers to finish up with the data in the pipe.
             #
             outt.join()
-            errt.join()
+            ##errt.join()
             del outt
-            del errt
+            ##del errt
             os.close(rpipe1)
-            os.close(rpipe2)
+            ##os.close(rpipe2)
             
     except WindowsError, err:
             raise ApplicationError, "Could not execute the command: "+cmd+"\tError message: "+str(err)
